@@ -159,5 +159,8 @@ class Struct:
         return {self.name: content}
 
     def as_others_param(self, other_struct):  # TODO: debug
+        if self.args:
+            arg = ", ".join([f"{self.args[i]}=${other_struct.args[i]}" for i in range(len(self.args))])
+            return f"{self._name}[{arg}]"
+        return self._name
 
-        return f"{self._name}[{self.args[0]}=${other_struct.args[0]}]"
